@@ -16,7 +16,7 @@ use namespace::clean;
 # Always remember to do all digits for the version even if they're 0
 # i.e. first release of 0.XX *must* be 0.XX000. This avoids fBSD ports
 # brain damage and presumably various other packaging systems too
-our $VERSION = '0.07039';
+our $VERSION = '0.07040';
 
 __PACKAGE__->mk_group_accessors('inherited', qw/
                                 _loader_args
@@ -675,6 +675,10 @@ andrewalker: André Walker <andre@andrewalker.net>
 
 mattp: Matt Phillips <mattp@cpan.org>
 
+Dag-Erling Smørgrav <des@des.no>
+
+moritz: Moritz Lenz <moritz@faui2k3.org>
+
 ... and lots of other folks. If we forgot you, please write the current
 maintainer or RT.
 
