@@ -13,7 +13,7 @@ use namespace::clean;
 
 use DBIx::Class::Schema::Loader::Table ();
 
-our $VERSION = '0.07038';
+our $VERSION = '0.07040';
 
 =head1 NAME
 
@@ -75,7 +75,7 @@ EOF
         my ($col, $constname, $seq) = @$row;
         push(@{$keydata{$constname}}, [ $seq, $self->_lc($col) ]);
     }
-    foreach my $keyname (keys %keydata) {
+    foreach my $keyname (sort keys %keydata) {
         my @ordered_cols = map { $_->[1] } sort { $a->[0] <=> $b->[0] }
             @{$keydata{$keyname}};
         push(@uniqs, [ $keyname => \@ordered_cols ]);
@@ -152,11 +152,14 @@ EOF
 }
 
 
-# DBD::DB2 doesn't follow the DBI API for ->tables
+# DBD::DB2 doesn't follow the DBI API for ->tables (pre 1.85), but since its
+# backwards compatible we don't change it.
+# DBD::DB2 1.85 and beyond default TABLE_NAME to '', previously defaulted to
+# '%'. so we supply it.
 sub _dbh_tables {
     my ($self, $schema) = @_;
 
-    return $self->dbh->tables($schema ? { TABLE_SCHEM => $schema } : undef);
+    return $self->dbh->tables($schema ? { TABLE_SCHEM => $schema, TABLE_NAME => '%' } : undef);
 }
 
 sub _columns_info_for {
